@@ -9,6 +9,8 @@ OC.L10N.register(
     "Cancel" : "Diddymu",
     "Open" : "Ar Agor",
     "Details" : "Manylion",
+    "General" : "Cyffredinol",
+    "Search" : "Chwilio",
     "Tags" : "Tagiau",
     "Activity" : "Gweithred",
     "Undo" : "Dadwneud",
@@ -25,15 +27,14 @@ OC.L10N.register(
     "Description" : "Disgrifiad",
     "Select Date" : "Dewis Dyddiad",
     "seconds ago" : "eiliad yn ôl",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
-    "Search" : "Chwilio",
     "Shared with you" : "Shared with you",
     "No reminder" : "Dim nodyn atgoffa",
     "An error occurred" : "Digwyddodd gwall",
     "Export" : "Allforio",
-    "Today" : "Heddiw",
     "Close" : "Cau",
     "Share" : "Rhannu",
-    "Personal" : "Personol"
+    "Personal" : "Personol",
+    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
+    "Today" : "Heddiw"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
