@@ -10,7 +10,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "Could not write file to disk" : "No fue posible escribir a disco",
     "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
-    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "%s on %s" : "%s en %s",
     "Finished" : "Terminado",
@@ -29,6 +28,8 @@ OC.L10N.register(
     "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
+    "General" : "General",
+    "Search" : "Buscar",
     "Sharing" : "Compartiendo",
     "Tags" : "Etiquetas",
     "Activity" : "Actividad",
@@ -53,10 +54,6 @@ OC.L10N.register(
     "Remove due date" : "Eliminar fecha de expiración",
     "(group)" : "(grupo)",
     "seconds ago" : "hace segundos",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Action" : "Acción",
-    "Search" : "Buscar",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
     "Cancel edit" : "Cancelar edición",
@@ -68,11 +65,15 @@ OC.L10N.register(
     "Delete board" : "Borrar tableros",
     "Advanced options" : "Opciones avanzadas",
     "Export" : "Exportar",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
     "Close" : "Cerrar",
     "Due date" : "Fecha de vencimiento",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Action" : "Acción",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
