@@ -85,7 +85,6 @@ OC.L10N.register(
     "Cards due tomorrow" : "Tarjetas para mañana",
     "Upcoming cards" : "Tarjetas próximas",
     "Load more" : "Cargar más",
-    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "Deck board" : "Tablero de Deck",
     "%s on %s" : "%s en %s",
@@ -125,6 +124,9 @@ OC.L10N.register(
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Open details" : "Abrir detalles",
     "Details" : "Detalles",
+    "General" : "General",
+    "Appearance" : "Apariencia",
+    "Search" : "Buscar",
     "Sharing" : "Compartiendo",
     "Tags" : "Etiquetas",
     "Activity" : "Actividad",
@@ -163,14 +165,6 @@ OC.L10N.register(
     "(group)" : "(grupo)",
     "Delete card" : "Eliminar tarjeta",
     "seconds ago" : "hace segundos",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Action" : "Acción",
-    "Shift" : "Mayús",
-    "Ctrl" : "Ctrl",
-    "Search" : "Buscar",
-    "Enter" : "Intro",
-    "Space" : "Espacio",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
     "Cancel edit" : "Cancelar edición",
@@ -192,6 +186,14 @@ OC.L10N.register(
     "Error creating the share" : "Error creando el recurso compartido",
     "Share" : "Compartir",
     "Personal" : "Personal",
+    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Action" : "Acción",
+    "Shift" : "Mayús",
+    "Ctrl" : "Ctrl",
+    "Enter" : "Intro",
+    "Space" : "Espacio",
     "Today" : "Hoy",
     "Tomorrow" : "Mañana"
 },
