@@ -132,6 +132,12 @@ OC.L10N.register(
     "Show card cover images" : "Näytä korttien kansikuvat",
     "Open details" : "Avaa yksityiskohdat",
     "Details" : "Tiedot",
+    "Deck settings" : "Pakan asetukset",
+    "General" : "Yleiset",
+    "Appearance" : "Ulkoasu",
+    "Show boards in calendar/tasks" : "Näytä taulut kalenterissa ja tehtävissä",
+    "Search" : "Etsi",
+    "Mark card as completed/not completed" : "Merkitse kortti valmiiksi/avoimeksi",
     "Loading board" : "Ladataan taulua",
     "Board not found" : "Taulua ei löydy",
     "Create a new list to add cards to this board" : "Lisää uusi lista lisätäksesi kortteja tälle taululle",
@@ -222,17 +228,9 @@ OC.L10N.register(
     "Unassign myself" : "Poista määritys minulta",
     "Delete card" : "Poista kortti",
     "seconds ago" : "sekuntia sitten",
-    "Keyboard shortcuts" : "Pikanäppäimet",
-    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
-    "Action" : "Toiminto",
-    "Shift" : "Siirrä",
-    "Search" : "Etsi",
-    "Mark card as completed/not completed" : "Merkitse kortti valmiiksi/avoimeksi",
     "All boards" : "Kaikki taulut",
     "Archived boards" : "Arkistoidut taulut",
     "Shared with you" : "Jaettu kanssasi",
-    "Deck settings" : "Pakan asetukset",
-    "Show boards in calendar/tasks" : "Näytä taulut kalenterissa ja tehtävissä",
     "Cancel edit" : "Peruuta muokkaus",
     "Board {0} deleted" : "Taulu {0} poistettu",
     "All cards" : "Kaikki kortit",
@@ -285,6 +283,10 @@ OC.L10N.register(
     "Example Task 3" : "Esimerkkitehtävä 3",
     "Example Task 2" : "Esimerkkitehtävä 2",
     "Example Task 1" : "Esimerkkitehtävä 1",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
+    "Action" : "Toiminto",
+    "Shift" : "Siirrä",
     "Today" : "Tänään",
     "Tomorrow" : "Huomenna"
 },
