@@ -166,6 +166,29 @@ OC.L10N.register(
     "Show card cover images" : "カードの画像を表示する",
     "Open details" : "詳細を開く",
     "Details" : "詳細",
+    "Deck settings" : "デック設定",
+    "General" : "一般",
+    "Use bigger card view" : "大きなカードビューを使用する",
+    "Appearance" : "表示",
+    "Show card ID badge" : "カードIDバジを表示",
+    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
+    "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
+    "Board actions" : "ボードアクション",
+    "Scroll sideways" : "横にスクロール",
+    "Navigate between cards" : "カード間を移動する",
+    "Close card details" : "カードの詳細を閉じる",
+    "Search" : "検索",
+    "Show card filters" : "カードフィルターを表示",
+    "Clear card filters" : "カードフィルターを削除",
+    "Show those shortcuts" : "これらのショートカットを表示する",
+    "Card actions" : "カードアクション",
+    "Open card details" : "カードの詳細を開く",
+    "Edit the card title" : "カードタイトルを編集する",
+    "Assign yourself to the current card" : "カードを自分に割り当てる",
+    "Archive/unarchive the current card" : "現在のカードをアーカイブ/アーカイブ解除",
+    "Mark card as completed/not completed" : "カードを完了/未完了にマークする",
+    "Open card menu" : "カードメニューを開く",
     "Currently present people" : "現在出席している人々",
     "Loading board" : "ボードを読み込み中",
     "Board not found" : "ボードが見つかりません",
@@ -281,41 +304,9 @@ OC.L10N.register(
     "Mark as not done" : "未完成のマーク",
     "Delete card" : "カードを削除する",
     "seconds ago" : "数秒前",
-    "Keyboard shortcuts" : "キーボードショートカット",
-    "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
-    "Board actions" : "ボードアクション",
-    "Keyboard shortcut" : "キーボードショートカット",
-    "Action" : "アクション",
-    "Shift" : "Shift",
-    "Scroll" : "スクロール",
-    "Scroll sideways" : "横にスクロール",
-    "Navigate between cards" : "カード間を移動する",
-    "Esc" : "Esc",
-    "Close card details" : "カードの詳細を閉じる",
-    "Ctrl" : "Ctrl",
-    "Search" : "検索",
-    "Show card filters" : "カードフィルターを表示",
-    "Clear card filters" : "カードフィルターを削除",
-    "Show help dialog" : "ヘルプダイアログを表示",
-    "Card actions" : "カードアクション",
-    "The following actions can be triggered on the currently highlighted card" : "現在ハイライトされているカードに対して以下のアクションを起こすことができる。",
-    "Enter" : "Enter",
-    "Space" : "スペース",
-    "Open card details" : "カードの詳細を開く",
-    "Edit the card title" : "カードタイトルを編集する",
-    "Assign yourself to the current card" : "カードを自分に割り当てる",
-    "Archive/unarchive the current card" : "現在のカードをアーカイブ/アーカイブ解除",
-    "Mark card as completed/not completed" : "カードを完了/未完了にマークする",
-    "Open card menu" : "カードメニューを開く",
     "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
-    "Deck settings" : "デック設定",
-    "Use bigger card view" : "大きなカードビューを使用する",
-    "Show card ID badge" : "カードIDバジを表示",
-    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
-    "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
     "Cancel edit" : "編集をキャンセル",
     "Board {0} deleted" : "ボード {0} 削除済み",
     "All cards" : "すべてのカード",
@@ -382,6 +373,18 @@ OC.L10N.register(
     "Example Task 3" : "タスク3の例",
     "Example Task 2" : "タスク2の例",
     "Example Task 1" : "タスク1の例",
+    "Keyboard shortcuts" : "キーボードショートカット",
+    "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
+    "Keyboard shortcut" : "キーボードショートカット",
+    "Action" : "アクション",
+    "Shift" : "Shift",
+    "Scroll" : "スクロール",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "ヘルプダイアログを表示",
+    "The following actions can be triggered on the currently highlighted card" : "現在ハイライトされているカードに対して以下のアクションを起こすことができる。",
+    "Enter" : "Enter",
+    "Space" : "スペース",
     "Today" : "今日",
     "Tomorrow" : "明日",
     "No due" : "日付なし"
