@@ -1,14 +1,16 @@
 OC.L10N.register(
     "deck",
     {
-    "In Progress" : "A Beaarbechtung",
-    "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
     "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
     "Missing a temporary folder" : "Et feelt en temporären Dossier",
+    "In Progress" : "A Beaarbechtung",
+    "Done" : "Done",
     "Cancel" : "Ofbriechen",
     "Completed" : "Erfëllt",
     "Details" : "Detailer",
+    "General" : "Allgemeng",
+    "Search" : "Search",
     "Sharing" : "Gedeelt",
     "Tags" : "Tags",
     "Activity" : "Aktivitéit",
@@ -18,21 +20,21 @@ OC.L10N.register(
     "Delete" : "Läschen",
     "Edit" : "Änneren",
     "Download" : "Eroflueden",
-    "Comments" : "Kommentarer",
     "Modified" : "Geännert",
+    "Comments" : "Kommentarer",
     "Save" : "Späicheren",
+    "Created:" : "Erstallt:",
     "Reply" : "Äntwerten",
     "Update" : "Update",
-    "Created:" : "Erstallt:",
     "Description" : "Beschreiwung",
     "seconds ago" : "Sekonnen hier",
-    "Search" : "Search",
     "Shared with you" : "Mat dir gedeelt",
     "Advanced options" : "Erweidert Astellungen",
-    "Today" : "Haut",
-    "Tomorrow" : "Muer",
+    "Export" : "Exportéieren",
     "Close" : "Zoumaachen",
     "Share" : "Deelen",
-    "Personal" : "Perséinlech"
+    "Personal" : "Perséinlech",
+    "Today" : "Haut",
+    "Tomorrow" : "Muer"
 },
 "nplurals=2; plural=(n != 1);");
