@@ -138,6 +138,11 @@ OC.L10N.register(
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
     "Open details" : "Atverti išsamesnę informaciją",
     "Details" : "Išsamiau",
+    "General" : "Bendra",
+    "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
+    "Appearance" : "Išvaizda",
+    "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
+    "Search" : "Ieškoti",
     "Loading board" : "Įkeliama lenta",
     "Board not found" : "Lenta nerasta",
     "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
@@ -223,17 +228,9 @@ OC.L10N.register(
     "Assign to me" : "Priskirti sau",
     "Delete card" : "Ištrinti kortelę",
     "seconds ago" : "prieš keletą sekundžių",
-    "Keyboard shortcuts" : "Spartieji klavišai",
-    "Keyboard shortcut" : "Spartusis klavišas",
-    "Action" : "Veiksmas",
-    "Shift" : "Lyg2",
-    "Ctrl" : "Vald",
-    "Search" : "Ieškoti",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
-    "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
-    "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
     "Cancel edit" : "Atsisakyti taisymo",
     "Board {0} deleted" : "Lenta {0} ištrinta",
     "All cards" : "Visos kortelės",
@@ -286,6 +283,11 @@ OC.L10N.register(
     "Example Task 3" : "Pavyzdinė užduotis 3",
     "Example Task 2" : "Pavyzdinė užduotis 2",
     "Example Task 1" : "Pavyzdinė užduotis 1",
+    "Keyboard shortcuts" : "Spartieji klavišai",
+    "Keyboard shortcut" : "Spartusis klavišas",
+    "Action" : "Veiksmas",
+    "Shift" : "Lyg2",
+    "Ctrl" : "Vald",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino"
