@@ -9,6 +9,9 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Completed" : "Fullført",
     "Details" : "Detaljar",
+    "General" : "Generelt",
+    "Appearance" : "Utsjånad",
+    "Search" : "Søk",
     "Sharing" : "Deling",
     "Tags" : "Emneord",
     "Activity" : "Aktivitet",
@@ -29,14 +32,13 @@ OC.L10N.register(
     "Update" : "Oppdater",
     "Description" : "Skildring",
     "seconds ago" : "sekund sidan",
-    "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Search" : "Søk",
     "Shared with you" : "Shared with you",
     "An error occurred" : "Det oppstod ein feil.",
     "Export" : "Eksporter",
-    "Today" : "I dag",
     "Close" : "Lat att",
     "Share" : "Del",
-    "Personal" : "Personleg"
+    "Personal" : "Personleg",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
+    "Today" : "I dag"
 },
 "nplurals=2; plural=(n != 1);");
