@@ -24,6 +24,9 @@ OC.L10N.register(
     "Completed" : "เสร็จแล้ว",
     "Overdue" : "เกินกำหนด",
     "Details" : "รายละเอียด",
+    "General" : "ทั่วไป",
+    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Search" : "ค้นหา",
     "Sharing" : "การแชร์",
     "Tags" : "แท็ก",
     "Activity" : "กิจกรรม",
@@ -46,9 +49,6 @@ OC.L10N.register(
     "Description" : "รายละเอียด",
     "(group)" : "(กลุ่ม)",
     "seconds ago" : "วินาทีที่ผ่านมา",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
-    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
-    "Search" : "ค้นหา",
     "Shared with you" : "แชร์กับคุณ",
     "An error occurred" : "เกิดข้อผิดพลาด",
     "Edit board" : "แก้ไขกระดาน",
@@ -60,6 +60,8 @@ OC.L10N.register(
     "Due date" : "วันที่ครบกำหนด",
     "Share" : "แชร์",
     "Personal" : "ส่วนตัว",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
     "Today" : "วันนี้",
     "Tomorrow" : "พรุ่งนี้"
 },
