@@ -181,6 +181,29 @@ OC.L10N.register(
     "Show card cover images" : "显示卡片封面图片",
     "Open details" : "打开详情",
     "Details" : "详情",
+    "Deck settings" : "看板设置",
+    "General" : "常规",
+    "Use bigger card view" : "使用较大的卡片视图",
+    "Appearance" : "外观",
+    "Show card ID badge" : "显示卡片ID序号",
+    "Show boards in calendar/tasks" : "在日历/任务中显示看板",
+    "Limit board creation to some groups" : "限制某些组可以创建看板",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
+    "Board actions" : "面板操作",
+    "Scroll sideways" : "侧向滚动",
+    "Navigate between cards" : "在卡片之间导航",
+    "Close card details" : "关闭卡详细信息",
+    "Search" : "搜索",
+    "Show card filters" : "显示卡片过滤器",
+    "Clear card filters" : "清除卡片过滤器",
+    "Show those shortcuts" : "显示快捷键",
+    "Card actions" : "卡片操作",
+    "Open card details" : "打开卡片详细信息",
+    "Edit the card title" : "编辑卡片标题",
+    "Assign yourself to the current card" : "将自己分配给当前卡片",
+    "Archive/unarchive the current card" : "存档/取消存档当前卡片",
+    "Mark card as completed/not completed" : "将卡片标记为已完成/未完成",
+    "Open card menu" : "打开卡片菜单",
     "Currently present people" : "当前在线的人",
     "Loading board" : "正在加载面板",
     "Board not found" : "未找到面板",
@@ -298,41 +321,9 @@ OC.L10N.register(
     "Mark as not done" : "标记为未完成",
     "Delete card" : "删除卡片",
     "seconds ago" : "几秒前",
-    "Keyboard shortcuts" : "键盘快捷键",
-    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
-    "Board actions" : "面板操作",
-    "Keyboard shortcut" : "键盘快捷键",
-    "Action" : "操作",
-    "Shift" : "Shift",
-    "Scroll" : "滚动",
-    "Scroll sideways" : "侧向滚动",
-    "Navigate between cards" : "在卡片之间导航",
-    "Esc" : "Esc",
-    "Close card details" : "关闭卡详细信息",
-    "Ctrl" : "Ctrl",
-    "Search" : "搜索",
-    "Show card filters" : "显示卡片过滤器",
-    "Clear card filters" : "清除卡片过滤器",
-    "Show help dialog" : "显示帮助对话框",
-    "Card actions" : "卡片操作",
-    "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
-    "Enter" : "输入",
-    "Space" : "空间",
-    "Open card details" : "打开卡片详细信息",
-    "Edit the card title" : "编辑卡片标题",
-    "Assign yourself to the current card" : "将自己分配给当前卡片",
-    "Archive/unarchive the current card" : "存档/取消存档当前卡片",
-    "Mark card as completed/not completed" : "将卡片标记为已完成/未完成",
-    "Open card menu" : "打开卡片菜单",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
-    "Deck settings" : "看板设置",
-    "Use bigger card view" : "使用较大的卡片视图",
-    "Show card ID badge" : "显示卡片ID序号",
-    "Show boards in calendar/tasks" : "在日历/任务中显示看板",
-    "Limit board creation to some groups" : "限制某些组可以创建看板",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
     "Cancel edit" : "取消编辑",
     "Save board" : "保存面板",
     "Board {0} deleted" : "面板{0} 被删除",
@@ -415,6 +406,18 @@ OC.L10N.register(
     "Example Task 3" : "示例任务 3",
     "Example Task 2" : "示例任务 2",
     "Example Task 1" : "示例任务 1",
+    "Keyboard shortcuts" : "键盘快捷键",
+    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
+    "Keyboard shortcut" : "键盘快捷键",
+    "Action" : "操作",
+    "Shift" : "Shift",
+    "Scroll" : "滚动",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "显示帮助对话框",
+    "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
+    "Enter" : "输入",
+    "Space" : "空间",
     "Today" : "今天",
     "Tomorrow" : "明天",
     "No due" : "没有到期的"
