@@ -181,6 +181,30 @@ OC.L10N.register(
     "Show card cover images" : "顯示卡片封面圖像",
     "Open details" : "開啟細節",
     "Details" : "詳情",
+    "Deck settings" : "看板設定",
+    "General" : "一般",
+    "Use bigger card view" : "使用較大的卡片視圖",
+    "Appearance" : "外觀",
+    "Show card ID badge" : "顯示卡片 ID 徽章",
+    "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
+    "Admin settings" : "管理員設定",
+    "Limit board creation to some groups" : "限制面板只能由某些群組創建",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
+    "Board actions" : "面板操作",
+    "Scroll sideways" : "橫向滾動",
+    "Navigate between cards" : "在卡片間移動",
+    "Close card details" : "關閉卡片詳細資訊",
+    "Search" : "搜尋",
+    "Show card filters" : "顯示卡片篩選條件",
+    "Clear card filters" : "清除卡片篩選條件",
+    "Show those shortcuts" : "顯示這些快捷鍵",
+    "Card actions" : "卡片操作",
+    "Open card details" : "打開卡片細節",
+    "Edit the card title" : "編輯卡片標題",
+    "Assign yourself to the current card" : "將自己指派給目前卡片",
+    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
+    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
+    "Open card menu" : "打開卡片選項單",
     "Currently present people" : "目前在場人仕",
     "Loading board" : "正在加載面板",
     "Board not found" : "未找到面板",
@@ -298,41 +322,9 @@ OC.L10N.register(
     "Mark as not done" : "標記為未完成",
     "Delete card" : "刪除卡片",
     "seconds ago" : "幾秒前",
-    "Keyboard shortcuts" : "鍵盤快捷鍵",
-    "Boost your productivity using Deck with keyboard shortcuts." : "提高您的生產力，在 Deck 上使用鍵盤快捷鍵。",
-    "Board actions" : "面板操作",
-    "Keyboard shortcut" : "鍵盤快捷鍵",
-    "Action" : "操作",
-    "Shift" : "轉移",
-    "Scroll" : "滾動",
-    "Scroll sideways" : "橫向滾動",
-    "Navigate between cards" : "在卡片間移動",
-    "Esc" : "Esc",
-    "Close card details" : "關閉卡片詳細資訊",
-    "Ctrl" : "Ctrl",
-    "Search" : "搜尋",
-    "Show card filters" : "顯示卡片篩選條件",
-    "Clear card filters" : "清除卡片篩選條件",
-    "Show help dialog" : "顯示幫助對話框",
-    "Card actions" : "卡片操作",
-    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下操作",
-    "Enter" : "輸入",
-    "Space" : "空間",
-    "Open card details" : "打開卡片細節",
-    "Edit the card title" : "編輯卡片標題",
-    "Assign yourself to the current card" : "將自己指派給目前卡片",
-    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
-    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
-    "Open card menu" : "打開卡片選項單",
     "All boards" : "全部面板",
     "Archived boards" : "已封存面板",
     "Shared with you" : "收到的分享",
-    "Deck settings" : "看板設定",
-    "Use bigger card view" : "使用較大的卡片視圖",
-    "Show card ID badge" : "顯示卡片 ID 徽章",
-    "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
-    "Limit board creation to some groups" : "限制面板只能由某些群組創建",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
     "Cancel edit" : "取消編輯",
     "Save board" : "保存面板",
     "Board {0} deleted" : "面板 {0} 已被刪除",
@@ -415,6 +407,18 @@ OC.L10N.register(
     "Example Task 3" : "示例任務 3",
     "Example Task 2" : "示例任務 2",
     "Example Task 1" : "示例任務 1",
+    "Keyboard shortcuts" : "鍵盤快捷鍵",
+    "Boost your productivity using Deck with keyboard shortcuts." : "提高您的生產力，在 Deck 上使用鍵盤快捷鍵。",
+    "Keyboard shortcut" : "鍵盤快捷鍵",
+    "Action" : "操作",
+    "Shift" : "轉移",
+    "Scroll" : "滾動",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "顯示幫助對話框",
+    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下操作",
+    "Enter" : "輸入",
+    "Space" : "空間",
     "Today" : "今日",
     "Tomorrow" : "明日",
     "No due" : "沒有到期的"
